Updog is a replacement for Python's SimpleHTTPServer.
It allows uploading and downloading via HTTP/S,
can set ad hoc SSL certificates and use HTTP basic auth.
The last version allows to generate a QR code to share the link
and also allows to display just image files in a more friendly way.
Installation
Install using pip:
pip3 install updog2
Usage
updog [-d DIRECTORY] [-p PORT] [-qr] [-q] [-i] [--password PASSWORD] [--ssl] [--version] [DIRECTORY]
| Argument | Description |
|---|---|
| -d DIRECTORY, --directory DIRECTORY | Root directory [Default=.] |
| -p PORT, --port PORT | Port to serve [Default=9090] |
| -qr, --qr | Show QR code to access the page |
| -q, --quiet | Do not display the QR code in the webpage |
| -i, --images | Show the images in the directory |
| --password PASSWORD | Use a password to access the page. (No username) |
| --ssl | Enable transport encryption via SSL |
| --version | Show version |
| -h, --help | Show help |
Examples
Serve from your current directory:
updog2
Serve from another directory:
updog2 -d /another/directory
Serve from port 1234:
updog2 -p 1234
Password protect the page:
updog2 --password examplePassword123!
Please note: updog uses HTTP basic authentication. To login, you should leave the username blank and just enter the password in the password field.
Use an SSL connection:
updog2 --ssl
Show a QR code to access the page:
updog2 -qr
Show the images in the directory:
updog2 -i
More examples:
updog2 /tmp/mydog -iqp 1234 --password examplePassword123! --ssl -qr
Notes
This project is a fork of updog by sc0tfree.
The original project is no longer maintained, so I decided to fork it and keep it up to date.
The principal changes I made can be found in the CHANGELOG.
Metadata
Release files for updog2 2.2.0
For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.
Source distribution (sdist)
| File | Size | Uploaded | Provenance | Actions |
|---|---|---|---|---|
| updog2-2.2.0.tar.gz | 4.7 MB | Without provenance | Details for updog2-2.2.0.tar.gz |
Built distribution (wheel)
| File | Interpreter | ABI | Platform | Actions Reset |
|---|---|---|---|---|
| updog2-2.2.0-py3-none-any.whl | Python 3 | none | any | Details for updog2-2.2.0-py3-none-any.whl |
Total release size: 9.4 MB
Release files / updog2-2.2.0.tar.gz
| Download URL | updog2-2.2.0.tar.gz |
|---|---|
| Size | 4.7 MB |
| Tags | Source |
|
SHA-256 checksum How to use checksums |
5b19a2a98f7b71225c50dfef2f45073aa1497138f57273b25a74f6454c1511fa
|
|
BLAKE2b-256 checksum How to use checksums |
191b9ccce623f460f3aab164df6d99823f3f216582f008afdbacdf9166b0de27
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.1.1 CPython/3.12.5
|
Release files / updog2-2.2.0-py3-none-any.whl
| Download URL | updog2-2.2.0-py3-none-any.whl |
|---|---|
| Size | 4.7 MB |
| Tags | Python 3 |
|
SHA-256 checksum How to use checksums |
3c73e6bb8339a71abac2f5e5c19ea543428be933961ea7d088ee801749066b85
|
|
BLAKE2b-256 checksum How to use checksums |
dd2753dcf0915588e0a449e4b743d7a6faad315d3df4a30a9c32ca3cbae72c6c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.1.1 CPython/3.12.5
|
Security for updog2 2.2.0
Provenance
Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.
No provenance found
None of the files in this release were uploaded with provenance metadata.
A note on package security
PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.
To learn more about protecting yourself from malicious actors, visit our package security documentation.